Fendt926 = {};

function Fendt926.prerequisitesPresent(specializations)
	return true;
end;

function Fendt926:load(xmlFile)

	self.exhaustFlap = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.exhaustFlap#index"));
	
	self.backupMinRpm = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#minRpm"), 1000);
	local motorMaxRpmStr = getXMLString(xmlFile, "vehicle.motor#maxRpm");
    local motorMaxRpm1, motorMaxRpm2, motorMaxRpm3 = Utils.getVectorFromString(motorMaxRpmStr);
    motorMaxRpm1 = Utils.getNoNil(motorMaxRpm1, 800);
    motorMaxRpm2 = Utils.getNoNil(motorMaxRpm2, 1000);
    motorMaxRpm3 = Utils.getNoNil(motorMaxRpm3, 1800);
	self.fieldMode = false;
	self.backUpBrakeForce = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#brakeForce"), 10)*2;
	self.backUpBackwardGearRatio = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#backwardGearRatio"), 1.5);
	self.backUpMaxRpm = motorMaxRpm3;
	self.temp = 25;
	self.coolingOn = false;
	self.coolingTemp = 0;
	self.tempOnBord = true;
	
	self.frontholder = {};
	self.frontholder.object = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.frontholder#index"));
	self.frontholder.refPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.frontholder#referencePoint"));
	self.frontholder.refRotX = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.frontholder#referenceRotX"), -1.04); 
	
	self.backholder = {};
	self.backholder.object = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backholder#index"));
	self.backholder.refPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backholder#referencePoint"));
	self.backholder.refRotX = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.backholder#referenceRotX"), 1.30); 
	
	local numWorkLights = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.worklights#count"), 0);
    self.worklights = {};
    for i=1, numWorkLights do
        local worklightnamei = string.format("vehicle.worklights.worklight%d", i);
        self.worklights[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, worklightnamei .. "#index"));
        setVisibility(self.worklights[i], false);
    end;
	self.worklightsActive = false;
	self.fourWheelMode = false;
	self.warmUp = 0.025;
	self.isStarted = false;
	
	self.helpPanelPath = Utils.getFilename("Fendt926HUD.png", self.baseDirectory);
	self.HudWidth = 0.386;
	self.HudHeight = 0.252; --old 0.256;
	self.HudPosX = 0.001;
	self.HudPosY = 0.001;
	self.helpPanelTextPosX = 0.002;
	self.helpPanelTextPosY = 0.356;
	self.helpPanelOverlay = Overlay:new("Helppanel", self.helpPanelPath, self.HudPosX, self.HudPoxY, self.HudWidth, self.HudHeight);
	self.helpPanelActive = false;

end;

function Fendt926:delete()
end;

function Fendt926:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Fendt926:keyEvent(unicode, sym, modifier, isDown)

end;

function Fendt926:stopMotor()
    self.motor.minRpm = self.backupMinRpm;
end;

function Fendt926:update(dt)

	if self.isMotorStarted then
		local rotX, rotY, rotZ = getRotation(self.exhaustFlap);
		local rotX = Utils.degToRad((self.motor.nonClampedMotorRpm+200)/28);
		if self.motor.minRpm < 0 then
			rotX = rotX-Utils.degToRad(self.motor.minRpm/28);
		else
			rotX = rotX
		end;
		if rotX < Utils.degToRad(0) then
			rotX = Utils.degToRad(0);
		end;
		if rotX > Utils.degToRad(70) then
			rotX = Utils.degToRad(70);
		end;
		setRotation(self.exhaustFlap, rotX*-1, rotY, rotZ);
	else
		setRotation(self.exhaustFlap, 0, rotY, rotZ);
	end;
	
	if self.isEntered then
		if InputBinding.hasEvent(InputBinding.WORKLIGHTS) then
			self.worklightsActive = not self.worklightsActive;
		end;
		if InputBinding.hasEvent(InputBinding.HELPPANELFENDT926) then
			self.helpPanelActive = not self.helpPanelActive;
		end;
		if InputBinding.hasEvent(InputBinding.MODE) then
			self.fieldMode = not self.fieldMode;
		end;
		if InputBinding.hasEvent(InputBinding.STEERMODE) then
			self.fourWheelMode = not self.fourWheelMode;
		end;
	end;
	
	for k, worklight in pairs(self.worklights) do
		setVisibility(worklight, self.worklightsActive);
	end;
		
	if self.frontholder.refPoint ~= nil and self.frontholder.refRotX ~= nil then
		local xRefPointFront, yRefPointFront, zRefPointFront = getRotation(self.frontholder.refPoint);
		local xRefPointBack, yRefPointBack, zRefPointBack = getRotation(self.backholder.refPoint);
		if math.floor(xRefPointFront*100)/100 ~= self.frontholder.refRotX then
			setRotation(self.frontholder.object, Utils.degToRad(69.21102), 0, 0);
		else
			setRotation(self.frontholder.object, Utils.degToRad(-1.34007), 0, 0);
		end;
		if math.floor(xRefPointBack*100)/100 ~= self.backholder.refRotX then
			setRotation(self.backholder.object, Utils.degToRad(-67.97647), 0, 0);
		else
			setRotation(self.backholder.object, Utils.degToRad(-0.30185), 0, 0);
		end;
	end;	
	
	if self.fourWheelMode then
		for i=1, table.getn(self.wheels) do
			self.wheels[1].driveMode = 1;
			self.wheels[2].driveMode = 1;
			self.wheels[3].driveMode = 1;
			self.wheels[4].driveMode = 1;
		end;
	else
		for i=1, table.getn(self.wheels) do
			self.wheels[1].driveMode = 0;
			self.wheels[2].driveMode = 0;
			self.wheels[3].driveMode = 1;
			self.wheels[4].driveMode = 1;
		end;
	end;
	
	self.input = InputBinding.getAnalogInputAxis(InputBinding.AXIS_FORWARD);
	if InputBinding.isAxisZero(self.input) then
		self.input = InputBinding.getDigitalInputAxis(InputBinding.AXIS_FORWARD);
	end;
	
	local maxRpm = self.motor:getMaxRpm();
	local torque = self.motor.torqueCurve:get(self.motor.lastMotorRpm);
	if self.input ~= 0 or self.motor.speedLevel ~= 0 then
		local differenz = maxRpm-self.motor.lastMotorRpm;
		if differenz <= 510 then
			self.motor.minRpm = self.motor.minRpm+(differenz/50);
		else
			self.motor.minRpm = self.motor.minRpm-(differenz/40);
		end;
		if self.motor.minRpm <= -650 then
			self.motor.minRpm = -650;
		elseif self.motor.minRpm >= 1100 then
			self.motor.minRpm = 1100;
		end;
		if self.fieldMode then
			self.motor.minRpm = (self.motor.minRpm-120);
		else
			self.motor.minRpm = self.motor.minRpm;
		end;
	end;
	
	if self.motor.lastMotorRpm > 0 then
		self.isStarted = true;
	else
		self.isStarted = false;
	end;
	
	if self.tempOnBord then
		if self.isStarted then
			local maxRpm = self.motor:getMaxRpm();
			local powerDifferenz = ((100/self.motor.lastMotorRpm)*maxRpm)-100;
			local lastMotorRpm = self.motor.lastMotorRpm;
			if powerDifferenz > 100 then
				powerDifferenz = 100;
			elseif powerDifferenz < 0 then
				powerDifferenz = 0;
			end;
			if maxRpm < self.motor.minRpm then
				maxRpm = self.motor.minRpm;
			end;
			if self.input == 0 or self.motor.speedLevel == 0 then
				if self.temp < 80 then
					self.temp = self.temp+(4/lastMotorRpm);
				else
					self.temp = self.temp-(2/lastMotorRpm);
				end;
			end;
			if powerDifferenz > 0 then
				self.temp = self.temp+(powerDifferenz/6000);
			end;
			if self.temp > 87 then
				self.coolingOn = true;
			end;
			if self.coolingOn == true and self.temp < 81 then
				self.coolingOn = false;
			end;
			if self.coolingOn == true then
				self.temp = self.temp-(6/lastMotorRpm);
			end;
		else
			self.temp = self.temp-(self.warmUp/10);
		end;
		if self.temp < 24 then
			self.temp = 24;
		end;
	end;
end;

function Fendt926:onLeave()
	for k, worklight in pairs(self.worklights) do
		setVisibility(worklight, false);
	end;
	self.worklightsActive = false;
	self.motor.minRpm = self.backupMinRpm;
end;

function Fendt926:draw()

	if self.helpPanelActive then
		self.helpPanelOverlay:render();
		renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.135, 0.025, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.HELPPANELFENDT926), g_i18n:getText("fendt926HelpPanelOn")));
		if self.moveableAttacher ~= nil then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.159, 0.024, string.format("Taste %s/%s: %s/%s", InputBinding.getButtonKeyName(InputBinding.ATTACHER_UP), InputBinding.getButtonKeyName(InputBinding.ATTACHER_DOWN), g_i18n:getText("attacherUp"), g_i18n:getText("attacherDown")));
		end;
		if not self.isMotorStarted and not self.automaticStart then	
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.207, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.IGNITION), g_i18n:getText("FendtStart")));
		else
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.351, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.IGNITION), g_i18n:getText("FendtStop")));
		end;
		if self.worklightsActive then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.183, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.WORKLIGHTS), g_i18n:getText("worklightOff")));
		else
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.183, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.WORKLIGHTS), g_i18n:getText("worklightOn")));
		end;
		if self.isMotorStarted then	
			if self.motor.speedLevel ~= 0 then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.207, 0.024, string.format("Taste %s/%s: %d RPM", InputBinding.getButtonKeyName(InputBinding.ACCELERATE), InputBinding.getButtonKeyName(InputBinding.DECELERATE), self.motor.maxRpm[self.motor.speedLevel]));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.207, 0.024, string.format("Taste %s/%s: %d RPM", InputBinding.getButtonKeyName(InputBinding.ACCELERATE), InputBinding.getButtonKeyName(InputBinding.DECELERATE), self.motor.maxRpm[3]));
			end;
			if self.reverse then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.231, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.FENDT_REVERSE), g_i18n:getText("FendtshuttleReverser1")));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.231, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.FENDT_REVERSE), g_i18n:getText("FendtshuttleReverser2")));
			end;
			if self.fourWheelMode then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.255, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.STEERMODE), g_i18n:getText("FendtAllrad")));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.255, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.STEERMODE), g_i18n:getText("FendtAllrad2")));
			end;
		end;
		if self.rundumleuchtenAnz > 0 and self:getIsActive() then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.279, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.RUNDUMLEUCHTE), g_i18n:getText("rundumleuchte")));
		end;
		if self.fieldMode then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.303, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.MODE), g_i18n:getText("fieldMode")));
		else
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.303, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.MODE), g_i18n:getText("transportMode")));
		end;
		if self.tempOnBord then
			local red = 0.0;
			local green = 0.0;
			local blue = 0.0;
			if self.temp < 63 then
				red = 0.0;
				green = 0.0;
				blue = 1.0;
			elseif self.temp >= 63 and self.temp <= 92 then
				blue = 0.0;
				red = 0.0;
				green = 1.0;
			elseif self.temp > 92 then
				red = 1.0;
				green = 0.0;
				blue = 0.0;
			end;
			setTextColor(red, green, blue, 1.0);
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.327, 0.024, string.format("                          %d 'C", self.temp));
			setTextColor(1.0, 1.0, 1.0, 1.0);
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.327, 0.024, string.format("Khlmitteltemperatur:"));
		end;
	else
		if not self.isMotorStarted and not self.automaticStart then	
			g_currentMission:addHelpButtonText(g_i18n:getText("FendtStart"), InputBinding.IGNITION);
		end;
		g_currentMission:addHelpButtonText(g_i18n:getText("fendt926HelpPanelOff"), InputBinding.HELPPANELFENDT926);
	end;
end;

function Fendt926:validateAttacherJoint(implement, jointDesc, dt)
    return true;
end;

function Fendt926:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)

	local loadTemp = getXMLFloat(xmlFile, key.."#temp");
	if loadTemp ~= nil then
		self.temp = loadTemp;
	end;
	return BaseMission.VEHICLE_LOAD_OK;
end;

function Fendt926:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'temp="'..self.temp..'"';
    return attributes, nil;
end;